@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -260,12 +260,12 @@ void SieveScriptListBox::slotDelete()
 {
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
-        const int answer = KMessageBox::warningYesNo(this,
-                                                     i18n("Do you want to delete \"%1\" script?", item->text()),
-                                                     i18nc("@title:window", "Delete Script"),
-                                                     KStandardGuiItem::del(),
-                                                     KStandardGuiItem::cancel());
-        if (answer == KMessageBox::Yes) {
+        const int answer = KMessageBox::warningTwoActions(this,
+                                                          i18n("Do you want to delete \"%1\" script?", item->text()),
+                                                          i18nc("@title:window", "Delete Script"),
+                                                          KStandardGuiItem::del(),
+                                                          KStandardGuiItem::cancel());
+        if (answer == KMessageBox::ButtonCode::PrimaryAction) {
             auto itemScript = static_cast<SieveScriptListItem *>(item);
             Q_EMIT removePage(itemScript->scriptPage());
             delete item;
