@@ -21,13 +21,18 @@
 
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QTimer>
 #include <QVBoxLayout>
+#include <QWindow>
 
 using namespace KSieveUi;
-
+namespace
+{
+static const char mySieveDebugDialogGroupName[] = "SieveDebugDialog";
+}
 SieveDebugDialog::SieveDebugDialog(SieveImapPasswordProvider *passwordProvider, QWidget *parent)
     : QDialog(parent)
     , mPasswordProvider(passwordProvider)
@@ -77,17 +82,18 @@ SieveDebugDialog::~SieveDebugDialog()
 
 void SieveDebugDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "SieveDebugDialog");
-    const QSize sizeDialog = group.readEntry("Size", QSize(640, 480));
-    if (sizeDialog.isValid()) {
-        resize(sizeDialog);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(640, 480));
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveDebugDialogGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void SieveDebugDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "SieveDebugDialog");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveDebugDialogGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
 
 void SieveDebugDialog::slotShutDownJob()
@@ -111,7 +117,7 @@ void SieveDebugDialog::slotDiagNextAccount()
         connect(mShutDownJob, &QTimer::timeout, this, &SieveDebugDialog::slotShutDownJob);
     }
     mShutDownJob->start(30 * 1000); // 30 seconds
-    const QString ident = mResourceIdentifier.first();
+    const QString ident = mResourceIdentifier.constFirst();
 
     mEdit->editor()->appendPlainText(i18n("Collecting data for account '%1'...\n", ident));
     mEdit->editor()->appendPlainText(i18n("------------------------------------------------------------\n"));
@@ -220,9 +226,8 @@ void SieveDebugDialog::slotGetScriptList(KManageSieve::SieveJob *job, bool succe
     if (caps.isEmpty()) {
         mEdit->editor()->appendPlainText(i18n("(No special capabilities available)"));
     } else {
-        QStringList::const_iterator end = caps.constEnd();
-        for (QStringList::const_iterator it = caps.constBegin(); it != end; ++it) {
-            mEdit->editor()->appendPlainText(QLatin1String("* ") + *it + QLatin1Char('\n'));
+        for (const auto &str : caps) {
+            mEdit->editor()->appendPlainText(QLatin1String("* ") + str + QLatin1Char('\n'));
         }
         mEdit->editor()->appendPlainText(QStringLiteral("\n"));
     }
@@ -233,9 +238,8 @@ void SieveDebugDialog::slotGetScriptList(KManageSieve::SieveJob *job, bool succe
         mEdit->editor()->appendPlainText(i18n("(No Sieve scripts available on this server)\n\n"));
     } else {
         mScriptList = scriptList;
-        QStringList::const_iterator end = scriptList.constEnd();
-        for (QStringList::const_iterator it = scriptList.constBegin(); it != end; ++it) {
-            mEdit->editor()->appendPlainText(QLatin1String("* ") + *it + QLatin1Char('\n'));
+        for (const auto &str : scriptList) {
+            mEdit->editor()->appendPlainText(QLatin1String("* ") + str + QLatin1Char('\n'));
         }
         mEdit->editor()->appendPlainText(QStringLiteral("\n"));
         mEdit->editor()->appendPlainText(i18n("Active script: '%1'\n\n", activeScript));
